@@ -5,8 +5,9 @@ but importing it does nothing
 
 from colored import fg, bg, attr
 
+
 def main():
-    print(f"{fg('dark_orange')}{attr('bold')}You called me!{attr('reset')}")
+    print(f"{fg('dark_orange')}{attr('bold')}You called me! Round 2!{attr('reset')}")
 
 
 if __name__ == "__main__":
